@@ -212,26 +212,20 @@ class PassClient:
                     if post_event_list:
                         metadata = list(post_event_list[0].keys())
                         event = post_event_list.pop(0)
-                        first_event_dt = (
-                            pre_event_list[0]["datetime"]
-                            if pre_event_list
-                            else event["datetime"]
-                        )
 
-                        last_event_dt = post_event_list[-1]["datetime"]
+                    header = self.header_pattern.search(
+                        group_dir["header"].decode(encoding="utf-8")
+                    ).groupdict()
 
                     if (
-                        first_event_dt
-                        and first_event_dt > start_datetime.replace(tzinfo=None)
-                        and last_event_dt
-                        and last_event_dt < end_datetime.replace(tzinfo=None)
+                        header
+                        and datetime.fromisoformat(header["datetime"])
+                        > start_datetime.replace(tzinfo=None)
+                        and datetime.fromisoformat(header["datetime"])
+                        < end_datetime.replace(tzinfo=None)
                     ) or timestamp:
                         yield InterlockEventData(
-                            header=self.header_pattern.search(
-                                group_dir["header"].decode(encoding="utf-8")
-                            ).groupdict()
-                            if "header" in return_fields
-                            else None,
+                            header=header if "header" in return_fields else None,
                             metadata=metadata if "metadata" in return_fields else None,
                             event=event if "event" in return_fields else None,
                             pre_events=pre_event_list
